import { _ as __nuxt_component_0 } from "./NocoIcon-d738cc24.mjs";
import { _ as _export_sfc, d as defineComponent, Y as Form, r as ref, u as useNuxtApp, a4 as useI18n, d_ as getDefaultConnectionConfig, d$ as ClientType, f as computed, w as watch, x as onMounted, a9 as nextTick, cF as resolveComponent, o as openBlock, l as createBlock, k as withCtx, e0 as clientTypes, e1 as sslUsage, n as Card, j as createVNode, b as createBaseVNode, z as toDisplayString, c7 as mergeProps, c as createElementBlock, h as renderList, E as createTextVNode, g as Fragment, B as createCommentVNode, dZ as projectTitleValidator, ds as fieldRequiredValidator, dG as navigateTo, $ as message, a2 as extractSdkResponseErrorMsg, e2 as getTestDatabaseName, aa as Modal, W as Input, X as __unplugin_components_2, aS as SelectOption, aT as __unplugin_components_3, e3 as __unplugin_components_4, du as __unplugin_components_3$1, O as Button, ah as __unplugin_components_7, aX as __unplugin_components_8, aY as Collapse, ar as __nuxt_component_1 } from "./entry-3ffd12c8.mjs";
import { r as readFile } from "./fileUtils-f5868683.mjs";
import { a as generateUniqueName } from "./generateName-b5da7037.mjs";
import { u as useSidebar } from "./index-75f7d1ec.mjs";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "create-external",
  setup(__props, { expose }) {
    expose();
    const useForm = Form.useForm;
    const loading = ref(false);
    const testSuccess = ref(false);
    const { $api, $e } = useNuxtApp();
    useSidebar({ hasSidebar: false });
    const { t } = useI18n();
    const formState = ref({
      title: "",
      dataSource: { ...getDefaultConnectionConfig(ClientType.MYSQL) },
      inflection: {
        inflectionColumn: "camelize",
        inflectionTable: "camelize"
      },
      sslUse: "No"
    });
    const validators = computed(() => {
      return {
        "title": [
          {
            required: true,
            message: "Project name is required"
          },
          projectTitleValidator
        ],
        "dataSource.client": [fieldRequiredValidator],
        ...formState.value.dataSource.client === ClientType.SQLITE ? {
          "dataSource.connection.connection.filename": [fieldRequiredValidator]
        } : {
          "dataSource.connection.host": [fieldRequiredValidator],
          "dataSource.connection.port": [fieldRequiredValidator],
          "dataSource.connection.user": [fieldRequiredValidator],
          "dataSource.connection.password": [fieldRequiredValidator],
          "dataSource.connection.database": [fieldRequiredValidator],
          ...[ClientType.PG, ClientType.MSSQL].includes(formState.value.dataSource.client) ? {
            "dataSource.searchPath.0": [fieldRequiredValidator]
          } : {}
        }
      };
    });
    const { validate, validateInfos } = useForm(formState.value, validators);
    const onClientChange = () => {
      formState.value.dataSource = { ...getDefaultConnectionConfig(formState.value.dataSource.client) };
    };
    const inflectionTypes = ["camelize", "none"];
    const configEditDlg = ref(false);
    watch(() => formState.value.title, (v) => formState.value.dataSource.connection.database = `${v == null ? void 0 : v.trim()}_noco`);
    formState.value.title = generateUniqueName();
    const caFileInput = ref();
    const keyFileInput = ref();
    const certFileInput = ref();
    const onFileSelect = (key, el) => {
      readFile(el, (content) => {
        if ("ssl" in formState.value.dataSource.connection && formState.value.dataSource.connection.ssl)
          formState.value.dataSource.connection.ssl[key] = content != null ? content : "";
      });
    };
    const sslFilesRequired = computed(() => {
      var _a;
      return ((_a = formState.value) == null ? void 0 : _a.sslUse) && formState.value.sslUse !== "No";
    });
    function getConnectionConfig() {
      const connection = {
        ...formState.value.dataSource.connection
      };
      if ("ssl" in connection && connection.ssl && (!sslFilesRequired || Object.values(connection.ssl).every((v) => !v))) {
        delete connection.ssl;
      }
      return connection;
    }
    const form = ref();
    const focusInvalidInput = () => {
      var _a, _b, _c, _d, _e;
      (_e = (_d = (_c = (_b = (_a = form == null ? void 0 : form.value) == null ? void 0 : _a.$el.querySelector(".ant-form-item-explain-error")) == null ? void 0 : _b.parentNode) == null ? void 0 : _c.parentNode) == null ? void 0 : _d.querySelector("input")) == null ? void 0 : _e.focus();
    };
    const createProject = async () => {
      try {
        await validate();
      } catch (e) {
        focusInvalidInput();
        return;
      }
      loading.value = true;
      try {
        const connection = getConnectionConfig();
        const config = { ...formState.value.dataSource, connection };
        const result = await $api.project.create({
          title: formState.value.title,
          bases: [
            {
              type: formState.value.dataSource.client,
              config,
              inflection_column: formState.value.inflection.inflectionColumn,
              inflection_table: formState.value.inflection.inflectionTable
            }
          ],
          external: true
        });
        $e("a:project:create:extdb");
        await navigateTo(`/nc/${result.id}`);
      } catch (e) {
        message.error(await extractSdkResponseErrorMsg(e));
      }
      loading.value = false;
    };
    const testConnection = async () => {
      try {
        await validate();
      } catch (e) {
        focusInvalidInput();
        return;
      }
      $e("a:project:create:extdb:test-connection", []);
      try {
        if (formState.value.dataSource.client === ClientType.SQLITE) {
          testSuccess.value = true;
        } else {
          const connection = getConnectionConfig();
          connection.database = getTestDatabaseName(formState.value.dataSource);
          const testConnectionConfig = {
            ...formState.value.dataSource,
            connection
          };
          const result = await $api.utils.testConnection(testConnectionConfig);
          if (result.code === 0) {
            testSuccess.value = true;
            Modal.confirm({
              title: t("msg.info.dbConnected"),
              icon: null,
              type: "success",
              okText: t("activity.OkSaveProject"),
              okType: "primary",
              cancelText: "Cancel",
              onOk: createProject
            });
          } else {
            testSuccess.value = false;
            message.error(`${t("msg.error.dbConnectionFailed")} ${result.message}`);
          }
        }
      } catch (e) {
        testSuccess.value = false;
        message.error(await extractSdkResponseErrorMsg(e));
      }
    };
    watch(() => formState.value.dataSource, () => testSuccess.value = false, { deep: true });
    onMounted(() => {
      nextTick(() => {
        setTimeout(() => {
          var _a, _b;
          const input = (_b = (_a = form.value) == null ? void 0 : _a.$el) == null ? void 0 : _b.querySelector("input[type=text]");
          input.setSelectionRange(0, formState.value.title.length);
          input.focus();
        }, 500);
      });
    });
    const __returned__ = { useForm, loading, testSuccess, $api, $e, t, formState, validators, validate, validateInfos, onClientChange, inflectionTypes, configEditDlg, caFileInput, keyFileInput, certFileInput, onFileSelect, sslFilesRequired, getConnectionConfig, form, focusInvalidInput, createProject, testConnection, ClientType, clientTypes, sslUsage };
    Object.defineProperty(__returned__, "__isScriptSetup", { enumerable: false, value: true });
    return __returned__;
  }
});
const _hoisted_1 = { class: "text-3xl text-center font-semibold mt-8 mb-4" };
const _hoisted_2 = { class: "flex gap-2" };
const _hoisted_3 = { class: "flex justify-end" };
const _hoisted_4 = { class: "flex justify-center gap-2" };
const _hoisted_5 = /* @__PURE__ */ createTextVNode(" Submit ");
function _sfc_render(_ctx, _cache, $props, $setup, $data, $options) {
  const _component_GeneralNocoIcon = __nuxt_component_0;
  const _component_a_input = Input;
  const _component_a_form_item = __unplugin_components_2;
  const _component_a_select_option = SelectOption;
  const _component_a_select = __unplugin_components_3;
  const _component_a_input_number = __unplugin_components_4;
  const _component_a_input_password = __unplugin_components_3$1;
  const _component_a_button = Button;
  const _component_a_tooltip = __unplugin_components_7;
  const _component_a_collapse_panel = __unplugin_components_8;
  const _component_a_collapse = Collapse;
  const _component_a_form = Form;
  const _component_MonacoEditor = __nuxt_component_1;
  const _component_a_card = Card;
  const _component_v_dialog = resolveComponent("v-dialog");
  return openBlock(), createBlock(_component_a_card, { class: "max-w-[600px] !mx-auto !mt-100px !mb-5 !shadow-md" }, {
    default: withCtx(() => [
      createVNode(_component_GeneralNocoIcon),
      createBaseVNode("h3", _hoisted_1, toDisplayString(_ctx.$t("activity.createProject")), 1),
      createVNode(_component_a_form, {
        ref: "form",
        model: $setup.formState,
        name: "external-project-create-form",
        layout: "horizontal",
        "label-col": { span: 8 },
        "wrapper-col": { span: 18 },
        class: "!pr-5"
      }, {
        default: withCtx(() => [
          createVNode(_component_a_form_item, mergeProps({
            label: _ctx.$t("placeholder.projName")
          }, $setup.validateInfos.title), {
            default: withCtx(() => [
              createVNode(_component_a_input, {
                value: $setup.formState.title,
                "onUpdate:value": _cache[0] || (_cache[0] = ($event) => $setup.formState.title = $event),
                size: "small",
                class: "nc-extdb-proj-name"
              }, null, 8, ["value"])
            ]),
            _: 1
          }, 16, ["label"]),
          createVNode(_component_a_form_item, mergeProps({
            label: _ctx.$t("labels.dbType")
          }, $setup.validateInfos["dataSource.client"]), {
            default: withCtx(() => [
              createVNode(_component_a_select, {
                value: $setup.formState.dataSource.client,
                "onUpdate:value": _cache[1] || (_cache[1] = ($event) => $setup.formState.dataSource.client = $event),
                size: "small",
                class: "nc-extdb-db-type",
                onChange: $setup.onClientChange
              }, {
                default: withCtx(() => [
                  (openBlock(true), createElementBlock(Fragment, null, renderList($setup.clientTypes, (client) => {
                    return openBlock(), createBlock(_component_a_select_option, {
                      key: client.value,
                      value: client.value
                    }, {
                      default: withCtx(() => [
                        createTextVNode(toDisplayString(client.text), 1)
                      ]),
                      _: 2
                    }, 1032, ["value"]);
                  }), 128))
                ]),
                _: 1
              }, 8, ["value"])
            ]),
            _: 1
          }, 16, ["label"]),
          $setup.formState.dataSource.client === $setup.ClientType.SQLITE ? (openBlock(), createBlock(_component_a_form_item, mergeProps({
            key: 0,
            label: _ctx.$t("labels.sqliteFile")
          }, $setup.validateInfos["dataSource.connection.connection.filename"]), {
            default: withCtx(() => [
              createVNode(_component_a_input, {
                value: $setup.formState.dataSource.connection.connection.filename,
                "onUpdate:value": _cache[2] || (_cache[2] = ($event) => $setup.formState.dataSource.connection.connection.filename = $event),
                size: "small"
              }, null, 8, ["value"])
            ]),
            _: 1
          }, 16, ["label"])) : (openBlock(), createElementBlock(Fragment, { key: 1 }, [
            createVNode(_component_a_form_item, mergeProps({
              label: _ctx.$t("labels.hostAddress")
            }, $setup.validateInfos["dataSource.connection.host"]), {
              default: withCtx(() => [
                createVNode(_component_a_input, {
                  value: $setup.formState.dataSource.connection.host,
                  "onUpdate:value": _cache[3] || (_cache[3] = ($event) => $setup.formState.dataSource.connection.host = $event),
                  size: "small",
                  class: "nc-extdb-host-address"
                }, null, 8, ["value"])
              ]),
              _: 1
            }, 16, ["label"]),
            createVNode(_component_a_form_item, mergeProps({
              label: _ctx.$t("labels.port")
            }, $setup.validateInfos["dataSource.connection.port"]), {
              default: withCtx(() => [
                createVNode(_component_a_input_number, {
                  value: $setup.formState.dataSource.connection.port,
                  "onUpdate:value": _cache[4] || (_cache[4] = ($event) => $setup.formState.dataSource.connection.port = $event),
                  class: "!w-full nc-extdb-host-port",
                  size: "small"
                }, null, 8, ["value"])
              ]),
              _: 1
            }, 16, ["label"]),
            createVNode(_component_a_form_item, mergeProps({
              label: _ctx.$t("labels.username")
            }, $setup.validateInfos["dataSource.connection.user"]), {
              default: withCtx(() => [
                createVNode(_component_a_input, {
                  value: $setup.formState.dataSource.connection.user,
                  "onUpdate:value": _cache[5] || (_cache[5] = ($event) => $setup.formState.dataSource.connection.user = $event),
                  size: "small",
                  class: "nc-extdb-host-user"
                }, null, 8, ["value"])
              ]),
              _: 1
            }, 16, ["label"]),
            createVNode(_component_a_form_item, {
              label: _ctx.$t("labels.password")
            }, {
              default: withCtx(() => [
                createVNode(_component_a_input_password, {
                  value: $setup.formState.dataSource.connection.password,
                  "onUpdate:value": _cache[6] || (_cache[6] = ($event) => $setup.formState.dataSource.connection.password = $event),
                  size: "small",
                  class: "nc-extdb-host-password"
                }, null, 8, ["value"])
              ]),
              _: 1
            }, 8, ["label"]),
            createVNode(_component_a_form_item, mergeProps({
              label: _ctx.$t("labels.database")
            }, $setup.validateInfos["dataSource.connection.database"]), {
              default: withCtx(() => [
                createVNode(_component_a_input, {
                  value: $setup.formState.dataSource.connection.database,
                  "onUpdate:value": _cache[7] || (_cache[7] = ($event) => $setup.formState.dataSource.connection.database = $event),
                  placeholder: _ctx.$t("labels.dbCreateIfNotExists"),
                  size: "small",
                  class: "nc-extdb-host-database"
                }, null, 8, ["value", "placeholder"])
              ]),
              _: 1
            }, 16, ["label"]),
            [$setup.ClientType.MSSQL, $setup.ClientType.PG].includes($setup.formState.dataSource.client) && $setup.formState.dataSource.searchPath ? (openBlock(), createBlock(_component_a_form_item, mergeProps({
              key: 0,
              label: _ctx.$t("labels.schemaName")
            }, $setup.validateInfos["dataSource.searchPath.0"]), {
              default: withCtx(() => [
                createVNode(_component_a_input, {
                  value: $setup.formState.dataSource.searchPath[0],
                  "onUpdate:value": _cache[8] || (_cache[8] = ($event) => $setup.formState.dataSource.searchPath[0] = $event),
                  size: "small"
                }, null, 8, ["value"])
              ]),
              _: 1
            }, 16, ["label"])) : createCommentVNode("", true),
            createVNode(_component_a_collapse, {
              ghost: "",
              "expand-icon-position": "right",
              class: "mt-6"
            }, {
              default: withCtx(() => [
                createVNode(_component_a_collapse_panel, {
                  key: "1",
                  header: _ctx.$t("title.advancedParameters")
                }, {
                  default: withCtx(() => [
                    createVNode(_component_a_form_item, { label: "SSL mode" }, {
                      default: withCtx(() => [
                        createVNode(_component_a_select, {
                          value: $setup.formState.sslUse,
                          "onUpdate:value": _cache[9] || (_cache[9] = ($event) => $setup.formState.sslUse = $event),
                          size: "small",
                          onChange: $setup.onClientChange
                        }, {
                          default: withCtx(() => [
                            (openBlock(true), createElementBlock(Fragment, null, renderList($setup.sslUsage, (opt) => {
                              return openBlock(), createBlock(_component_a_select_option, {
                                key: opt,
                                value: opt
                              }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(opt), 1)
                                ]),
                                _: 2
                              }, 1032, ["value"]);
                            }), 128))
                          ]),
                          _: 1
                        }, 8, ["value"])
                      ]),
                      _: 1
                    }),
                    createVNode(_component_a_form_item, { label: "SSL keys" }, {
                      default: withCtx(() => [
                        createBaseVNode("div", _hoisted_2, [
                          createVNode(_component_a_tooltip, { placement: "top" }, {
                            title: withCtx(() => [
                              createBaseVNode("span", null, toDisplayString(_ctx.$t("tooltip.clientCert")), 1)
                            ]),
                            default: withCtx(() => [
                              createVNode(_component_a_button, {
                                disabled: !$setup.sslFilesRequired,
                                size: "small",
                                class: "shadow",
                                onClick: _cache[10] || (_cache[10] = ($event) => $setup.certFileInput.click())
                              }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(_ctx.$t("labels.clientCert")), 1)
                                ]),
                                _: 1
                              }, 8, ["disabled"])
                            ]),
                            _: 1
                          }),
                          createVNode(_component_a_tooltip, { placement: "top" }, {
                            title: withCtx(() => [
                              createBaseVNode("span", null, toDisplayString(_ctx.$t("tooltip.clientKey")), 1)
                            ]),
                            default: withCtx(() => [
                              createVNode(_component_a_button, {
                                disabled: !$setup.sslFilesRequired,
                                size: "small",
                                class: "shadow",
                                onClick: _cache[11] || (_cache[11] = ($event) => $setup.keyFileInput.click())
                              }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(_ctx.$t("labels.clientKey")), 1)
                                ]),
                                _: 1
                              }, 8, ["disabled"])
                            ]),
                            _: 1
                          }),
                          createVNode(_component_a_tooltip, { placement: "top" }, {
                            title: withCtx(() => [
                              createBaseVNode("span", null, toDisplayString(_ctx.$t("tooltip.clientCA")), 1)
                            ]),
                            default: withCtx(() => [
                              createVNode(_component_a_button, {
                                disabled: !$setup.sslFilesRequired,
                                size: "small",
                                class: "shadow",
                                onClick: _cache[12] || (_cache[12] = ($event) => $setup.caFileInput.click())
                              }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(_ctx.$t("labels.serverCA")), 1)
                                ]),
                                _: 1
                              }, 8, ["disabled"])
                            ]),
                            _: 1
                          })
                        ])
                      ]),
                      _: 1
                    }),
                    createBaseVNode("input", {
                      ref: "caFileInput",
                      type: "file",
                      class: "!hidden",
                      onChange: _cache[13] || (_cache[13] = ($event) => $setup.onFileSelect("ca", $setup.caFileInput))
                    }, null, 544),
                    createBaseVNode("input", {
                      ref: "certFileInput",
                      type: "file",
                      class: "!hidden",
                      onChange: _cache[14] || (_cache[14] = ($event) => $setup.onFileSelect("cert", $setup.certFileInput))
                    }, null, 544),
                    createBaseVNode("input", {
                      ref: "keyFileInput",
                      type: "file",
                      class: "!hidden",
                      onChange: _cache[15] || (_cache[15] = ($event) => $setup.onFileSelect("key", $setup.keyFileInput))
                    }, null, 544),
                    createVNode(_component_a_form_item, {
                      label: _ctx.$t("labels.inflection.tableName")
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_a_select, {
                          value: $setup.formState.inflection.inflectionTable,
                          "onUpdate:value": _cache[16] || (_cache[16] = ($event) => $setup.formState.inflection.inflectionTable = $event),
                          size: "small",
                          onChange: $setup.onClientChange
                        }, {
                          default: withCtx(() => [
                            (openBlock(), createElementBlock(Fragment, null, renderList($setup.inflectionTypes, (type) => {
                              return createVNode(_component_a_select_option, {
                                key: type,
                                value: type
                              }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(type), 1)
                                ]),
                                _: 2
                              }, 1032, ["value"]);
                            }), 64))
                          ]),
                          _: 1
                        }, 8, ["value"])
                      ]),
                      _: 1
                    }, 8, ["label"]),
                    createVNode(_component_a_form_item, {
                      label: _ctx.$t("labels.inflection.columnName")
                    }, {
                      default: withCtx(() => [
                        createVNode(_component_a_select, {
                          value: $setup.formState.inflection.inflectionColumn,
                          "onUpdate:value": _cache[17] || (_cache[17] = ($event) => $setup.formState.inflection.inflectionColumn = $event),
                          size: "small",
                          onChange: $setup.onClientChange
                        }, {
                          default: withCtx(() => [
                            (openBlock(), createElementBlock(Fragment, null, renderList($setup.inflectionTypes, (type) => {
                              return createVNode(_component_a_select_option, {
                                key: type,
                                value: type
                              }, {
                                default: withCtx(() => [
                                  createTextVNode(toDisplayString(type), 1)
                                ]),
                                _: 2
                              }, 1032, ["value"]);
                            }), 64))
                          ]),
                          _: 1
                        }, 8, ["value"])
                      ]),
                      _: 1
                    }, 8, ["label"]),
                    createBaseVNode("div", _hoisted_3, [
                      createVNode(_component_a_button, {
                        size: "small",
                        class: "!shadow-md",
                        onClick: _cache[18] || (_cache[18] = ($event) => $setup.configEditDlg = true)
                      }, {
                        default: withCtx(() => [
                          createTextVNode(toDisplayString(_ctx.$t("activity.editConnJson")), 1)
                        ]),
                        _: 1
                      })
                    ])
                  ]),
                  _: 1
                }, 8, ["header"])
              ]),
              _: 1
            })
          ], 64)),
          createVNode(_component_a_form_item, { class: "flex justify-center mt-5" }, {
            default: withCtx(() => [
              createBaseVNode("div", _hoisted_4, [
                createVNode(_component_a_button, {
                  type: "primary",
                  ghost: "",
                  class: "nc-extdb-btn-test-connection",
                  onClick: $setup.testConnection
                }, {
                  default: withCtx(() => [
                    createTextVNode(toDisplayString(_ctx.$t("activity.testDbConn")), 1)
                  ]),
                  _: 1
                }),
                createVNode(_component_a_button, {
                  type: "primary",
                  disabled: !$setup.testSuccess,
                  class: "nc-extdb-btn-submit !shadow",
                  onClick: $setup.createProject
                }, {
                  default: withCtx(() => [
                    _hoisted_5
                  ]),
                  _: 1
                }, 8, ["disabled"])
              ])
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["model"]),
      createVNode(_component_v_dialog, {
        modelValue: $setup.configEditDlg,
        "onUpdate:modelValue": _cache[20] || (_cache[20] = ($event) => $setup.configEditDlg = $event)
      }, {
        default: withCtx(() => [
          createVNode(_component_a_card, null, {
            default: withCtx(() => [
              $setup.configEditDlg ? (openBlock(), createBlock(_component_MonacoEditor, {
                key: 0,
                modelValue: $setup.formState,
                "onUpdate:modelValue": _cache[19] || (_cache[19] = ($event) => $setup.formState = $event),
                class: "h-[400px] w-[600px]"
              }, null, 8, ["modelValue"])) : createCommentVNode("", true)
            ]),
            _: 1
          })
        ]),
        _: 1
      }, 8, ["modelValue"])
    ]),
    _: 1
  });
}
var createExternal = /* @__PURE__ */ _export_sfc(_sfc_main, [["render", _sfc_render], ["__scopeId", "data-v-307d3481"]]);
export { createExternal as default };
