import { di as isClient, aB as createEventHook, r as ref, w as watch, dj as isVNode, aH as h, u as useNuxtApp, d2 as render, dk as toReactive, dl as tryOnScopeDispose } from "./entry-3ffd12c8.mjs";
function useDialog(componentOrVNode, props = {}, mountTarget) {
  if (typeof document === "undefined" || !isClient) {
    console.warn("[useDialog]: Cannot use outside of browser!");
  }
  const closeHook = createEventHook();
  const mountedHook = createEventHook();
  const isMounted = ref(false);
  const domNode = document.createElement("div");
  const vNodeRef = ref();
  mountTarget = mountTarget ? "$el" in mountTarget ? mountTarget.$el : mountTarget : document.body;
  mountTarget.appendChild(domNode);
  const stop = watch(toReactive(props), (reactiveProps) => {
    const vNode = isVNode(componentOrVNode) ? componentOrVNode : h(componentOrVNode, reactiveProps);
    vNode.appContext = useNuxtApp().vueApp._context;
    vNodeRef.value = vNode;
    render(vNode, domNode);
    if (!isMounted.value)
      mountedHook.trigger();
  }, { deep: true, immediate: true, flush: "post" });
  tryOnScopeDispose(close);
  function close(debounce = 0) {
    setTimeout(() => {
      stop();
      render(null, domNode);
      setTimeout(() => {
        mountTarget.removeChild(domNode);
      }, 100);
      closeHook.trigger();
    }, debounce);
  }
  return {
    close,
    onClose: closeHook.on,
    onMounted: mountedHook.on,
    domNode,
    vNode: vNodeRef
  };
}
export { useDialog as u };
